const colorScale = d3.scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['red', 'yellow']);

const radiusScale = d3.scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([30, 20]);

const xPosition = (d,i) => 100 + i * 100;

export const fruitBowl = (selection, props) => {
  
  
  const bowl = selection.selectAll('rect')
  	.data([null])
    .enter().append('rect')
      .attr('x', 50)
      .attr('y', 150)
      .attr('width', 500)
      .attr('height', 200)
      .attr('rx', 200/2)
  		.attr('fill', '#f5ee9f');
  
  
  const groups = selection.selectAll('g')
  	.data(props.fruits, d => d.id);
  
  //enter
  const groupsEnter = groups.enter().append('g')
  	.style('opacity', 0)
    .attr('class', d => 'g-'+d.type)
  	.attr('transform', (d, i) => `translate(${xPosition(d,i)}, ${props.height/2})` );
  
  groupsEnter.merge(groups)
  	.transition(400)
  		.style('opacity', 1)
    	.attr('transform', (d, i) => `translate(${xPosition(d,i)}, ${props.height/2})` );
  
  //exit
  groups.exit()
  	.transition(400)
			.style('opacity', 0)
    .remove();

   
  
  
  //circles
  groupsEnter.append('circle')
      .attr('class', d => d.type)
    .merge(groups.select('circle'))
  		.on('mouseenter', d => props.setSelectedFruit(d.id))
  		.transition(400)
        .attr('r', d => radiusScale(d.type))
        .attr('fill', d => colorScale(d.type))
  			.attr('stroke', d => 
        	d.id == props.selectedFruit 
            ? '#000' 
            : 'none'
        );
  
  
  
  //texts
  groupsEnter.append('text')
  		.attr('class', d => 'text-'+d.type)
    .merge(groups.select('text'))
      .attr('r', d => radiusScale(d.type))
  		.attr('y', 50)
  		.text(d => d.type);
  
}